@@ -428,6 +428,26 @@ def move_to_downloads(linkids, uuid):
         return False
 
 
+def reset_in_downloads(linkids, uuid):
+    try:
+        if not internal.device or not is_device(internal.device):
+            get_device()
+        if internal.device:
+            try:
+                internal.device.downloads.reset_links(linkids, uuid)
+            except feedcrawler.myjdapi.TokenExpiredException:
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return False
+                internal.device.downloads.reset_links(linkids, uuid)
+            return True
+        else:
+            return False
+    except feedcrawler.myjdapi.MYJDException as e:
+        print(u"Fehler bei der Verbindung mit MyJDownloader: " + str(e))
+        return False
+
+
 def remove_from_linkgrabber(linkids, uuid):
     try:
         if not internal.device or not is_device(internal.device):
@@ -666,26 +686,6 @@ def retry_decrypt(linkids, uuid, links):
         return False
 
 
-def update_jdownloader():
-    try:
-        if not internal.device or not is_device(internal.device):
-            get_device()
-        if internal.device:
-            try:
-                internal.device.update.restart_and_update()
-            except feedcrawler.myjdapi.TokenExpiredException:
-                get_device()
-                if not internal.device or not is_device(internal.device):
-                    return False
-                internal.device.update.restart_and_update()
-            return True
-        else:
-            return False
-    except feedcrawler.myjdapi.MYJDException as e:
-        print(u"Fehler bei der Verbindung mit MyJDownloader: " + str(e))
-        return False
-
-
 def jdownloader_start():
     try:
         if not internal.device or not is_device(internal.device):
@@ -875,147 +875,6 @@ def hoster_check(decrypted_packages, title, known_packages):
     return [True, False]
 
 
-def package_merge(decrypted_packages, title, known_packages):
-    if not decrypted_packages:
-        return [False, False]
-
-    delete_packages = []
-    delete_linkids = []
-    delete_uuids = []
-    keep_linkids = []
-    keep_uuids = []
-
-    episodes = re.findall(r'E(\d{1,3})', title)
-    more_than_one_episode = False
-    valid_links = False
-
-    merge_first = package_merge_check(decrypted_packages, known_packages)
-    if merge_first:
-        decrypted_packages = merge_first[1]
-
-    if episodes:
-        int_episodes = []
-        for ep in episodes:
-            int_episodes.append(int(ep))
-        if len(int_episodes) > 1:
-            sorted_eps = sorted(int_episodes)
-            min_ep = sorted_eps[0]
-            max_ep = sorted_eps[-1]
-            all_episodes = list(range(min_ep, max_ep + 1))
-        else:
-            all_episodes = list(int_episodes)
-        all_episodes_merged = int("".join(str(int_episode) for int_episode in int_episodes))
-
-        if decrypted_packages:
-            fname_episodes = []
-            for dp in decrypted_packages:
-                if dp['uuid'] not in known_packages:
-                    fnames = dp['filenames']
-                    for fname in fnames:
-                        try:
-                            if re.match(r'.*S\d{1,3}E\d{1,3}.*', fname, flags=re.IGNORECASE):
-                                fname = re.findall(r'S\d{1,3}E(\d{1,3})', fname, flags=re.IGNORECASE).pop()
-                            else:
-                                fname = fname.replace("hddl8", "").replace("dd51", "").replace("264", "").replace("265",
-                                                                                                                  "")
-                        except:
-                            fname = fname.replace("hddl8", "").replace("dd51", "").replace("264", "").replace("265", "")
-                        fname_episode = "".join(re.findall(r'\d+', fname.split(".part")[0]))
-                        try:
-                            fname_episodes.append(str(int(fname_episode)))
-                        except:
-                            return [True, False]
-            replacer = longest_substr(fname_episodes)
-
-            new_fname_episodes = []
-            for new_ep_fname in fname_episodes:
-                try:
-                    new_fname_episodes.append(str(int(new_ep_fname.replace(replacer, ""))))
-                except:
-                    pass
-            replacer = longest_substr(new_fname_episodes)
-
-            newer_fname_episodes = []
-            for new_ep_fname in new_fname_episodes:
-                try:
-                    newer_fname_episodes.append(str(int(re.sub(replacer, "", new_ep_fname, 1))))
-                except:
-                    pass
-
-            replacer = longest_substr(newer_fname_episodes)
-
-            even_newer_fname_episodes = []
-            for newer_ep_fname in newer_fname_episodes:
-                try:
-                    even_newer_fname_episodes.append(str(int(re.sub(replacer, "", newer_ep_fname, 1))))
-                except:
-                    pass
-
-            if even_newer_fname_episodes:
-                fname_episodes = even_newer_fname_episodes
-            elif newer_fname_episodes:
-                fname_episodes = newer_fname_episodes
-            elif new_fname_episodes:
-                fname_episodes = new_fname_episodes
-
-            i = 0
-            for dp in decrypted_packages:
-                linkids = dp['linkids']
-                for link in linkids:
-                    delete_linkids.append(link)
-                uuid = dp['uuid']
-                delete_uuids.append(uuid)
-                if uuid not in known_packages:
-                    delete = True
-                    fnames = dp['filenames']
-                    for _ in fnames:
-                        try:
-                            if not fname_episodes[i] == replacer:
-                                fname_episode = int(fname_episodes[i])
-                                more_than_one_episode = True
-                            if fname_episode in all_episodes or fname_episode == all_episodes_merged:
-                                keep_linkids.append(linkids[i])
-                                if uuid not in keep_uuids:
-                                    keep_uuids.append(uuid)
-                                delete = False
-                        except:
-                            pass
-                        i += 1
-                    if delete:
-                        delete_packages.append(dp)
-    else:
-        if decrypted_packages:
-            i = 0
-            for dp in decrypted_packages:
-                linkids = dp['linkids']
-                for link in linkids:
-                    delete_linkids.append(link)
-                uuid = dp['uuid']
-                delete_uuids.append(uuid)
-                if uuid not in known_packages:
-                    delete = True
-                    links = split_urls(dp['urls'])
-                    for _ in links:
-                        try:
-                            keep_linkids.append(linkids[i])
-                            valid_links = True
-                        except:
-                            pass
-                        if uuid not in keep_uuids:
-                            keep_uuids.append(uuid)
-                        delete = False
-                        i += 1
-                    if delete:
-                        delete_packages.append(dp)
-
-    if more_than_one_episode or valid_links:
-        removed = remove_unfit_links(decrypted_packages, known_packages, keep_linkids, keep_uuids,
-                                     delete_linkids,
-                                     delete_uuids, delete_packages, title)
-        return [removed[0], removed[1]]
-    return [True, False]
-
-
 def package_merge_check(decrypted_packages, known_packages):
     mergables = []
     if decrypted_packages:
@@ -1089,24 +948,6 @@ def do_package_merge(title, uuids, linkids):
         return False
 
 
-def do_package_replace(old_package, cnl_package):
-    title = old_package['name']
-    path = old_package['path']
-    links = (ensure_string(old_package['urls']) + '\n' + ensure_string(cnl_package['urls'])).replace("\n\n", "\n")
-    links = links.replace(old_package['url'] + '\n', '').replace(old_package['url'], '')
-    linkids = cnl_package['linkids']
-    uuid = [cnl_package['uuid']]
-    internal.device = remove_from_linkgrabber(linkids, uuid)
-
-    linkids = old_package['linkids']
-    uuid = [old_package['uuid']]
-    if remove_from_linkgrabber(linkids, uuid):
-        if download(title, "", links, "", path, False):
-            print(u"[Click'n'Load-Automatik erfolgreich] - " + title)
-            return title
-    return False
-
-
 def do_add_decrypted(title, password, cnl_packages):
     linkids = []
     uuids = []
