@@ -11,7 +11,8 @@ import sys
 import time
 from functools import wraps
 
-from flask import Flask, request, redirect, send_from_directory, render_template, jsonify, Response
+from flask import Flask, request, redirect, render_template, send_from_directory, jsonify, Response
+from flask_cors import CORS
 from passlib.hash import pbkdf2_sha256
 from requests.packages.urllib3 import disable_warnings as disable_request_warnings
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -33,7 +34,6 @@ from feedcrawler.db import FeedDb
 from feedcrawler.db import ListDb
 from feedcrawler.myjd import check_device
 from feedcrawler.myjd import do_add_decrypted
-from feedcrawler.myjd import do_package_replace
 from feedcrawler.myjd import download
 from feedcrawler.myjd import get_device
 from feedcrawler.myjd import get_if_one_device
@@ -44,10 +44,9 @@ from feedcrawler.myjd import jdownloader_pause
 from feedcrawler.myjd import jdownloader_start
 from feedcrawler.myjd import jdownloader_stop
 from feedcrawler.myjd import move_to_downloads
-from feedcrawler.myjd import package_merge
 from feedcrawler.myjd import remove_from_linkgrabber
+from feedcrawler.myjd import reset_in_downloads
 from feedcrawler.myjd import retry_decrypt
-from feedcrawler.myjd import update_jdownloader
 from feedcrawler.notifiers import notify
 from feedcrawler.search import search
 
@@ -63,15 +62,55 @@ def app_container():
     if getattr(sys, 'frozen', False):
         base_dir = os.path.join(sys._MEIPASS)
 
-    app = Flask(__name__, template_folder=os.path.join(base_dir, 'web'))
-    app.config["TEMPLATES_AUTO_RELOAD"] = True
-
     general = CrawlerConfig('FeedCrawler')
     if general.get("prefix"):
         prefix = '/' + general.get("prefix")
     else:
         prefix = ""
 
+    def requires_auth(f):
+        @wraps(f)
+        def decorated(*args, **kwargs):
+            config = CrawlerConfig('FeedCrawler')
+            if config.get("auth_user") and config.get("auth_hash"):
+                auth = request.authorization
+                if not auth or not check_auth(config, auth.username, auth.password):
+                    return authenticate()
+            return f(*args, **kwargs)
+
+        return decorated
+
+    app = Flask(__name__, template_folder=os.path.join(base_dir, 'web/dist'))
+    CORS(app)
+
+    @app.route(prefix + '/', defaults={'path': ''}, methods=['GET'])
+    @app.route(prefix + '/<path:path>')
+    @requires_auth
+    def catch_all(path):
+        return render_template('index.html')
+
+    if prefix:
+        @app.route('/')
+        @requires_auth
+        def index_prefix():
+            return redirect(prefix)
+
+    @app.route(prefix + '/assets/<path:path>')
+    def static_files(path):
+        return send_from_directory(os.path.join(base_dir, 'web/dist/assets'), path)
+
+    @app.route(prefix + '/favicon.ico', methods=['GET'])
+    def static_favicon():
+        return send_from_directory(os.path.join(base_dir, 'web/dist'), 'favicon.ico')
+
+    @app.route(prefix + '/sponsors_helper/assets/<path:path>')
+    def static_files_helper(path):
+        return send_from_directory(os.path.join(base_dir, 'web/dist/assets'), path)
+
+    @app.route(prefix + '/sponsors_helper/favicon.ico', methods=['GET'])
+    def static_favicon_helper():
+        return send_from_directory(os.path.join(base_dir, 'web/dist'), 'favicon.ico')
+
     def check_auth(config, username, password):
         auth_hash = config.get("auth_hash")
         if auth_hash and "$pbkdf2-sha256" not in auth_hash:
@@ -92,18 +131,6 @@ def app_container():
                 ''', 401,
             {'WWW-Authenticate': 'Basic realm="FeedCrawler"'})
 
-    def requires_auth(f):
-        @wraps(f)
-        def decorated(*args, **kwargs):
-            config = CrawlerConfig('FeedCrawler')
-            if config.get("auth_user") and config.get("auth_hash"):
-                auth = request.authorization
-                if not auth or not check_auth(config, auth.username, auth.password):
-                    return authenticate()
-            return f(*args, **kwargs)
-
-        return decorated
-
     def to_int(i):
         if isinstance(i, bytes):
             i = i.decode()
@@ -123,22 +150,6 @@ def app_container():
     def check(site, db):
         return to_bool(str(db.retrieve(site)).replace("Blocked", "True"))
 
-    if prefix:
-        @app.route('/')
-        @requires_auth
-        def index_prefix():
-            return redirect(prefix)
-
-    @app.route(prefix + '/<path:path>')
-    @requires_auth
-    def send_html(path):
-        return send_from_directory(os.path.join(base_dir, 'web'), path)
-
-    @app.route(prefix + '/')
-    @requires_auth
-    def index():
-        return render_template('index.html')
-
     @app.route(prefix + "/api/log/", methods=['GET', 'DELETE'])
     @requires_auth
     def get_delete_log():
@@ -227,7 +238,6 @@ def app_container():
                                 "flaresolverr_proxy": general_conf.get("flaresolverr_proxy"),
                                 "english": general_conf.get("english"),
                                 "surround": general_conf.get("surround"),
-                                "closed_myjd_tab": general_conf.get("closed_myjd_tab"),
                                 "one_mirror_policy": general_conf.get("one_mirror_policy"),
                                 "packages_per_myjd_page": to_int(general_conf.get("packages_per_myjd_page")),
                             },
@@ -349,7 +359,6 @@ def app_container():
                 section.save("flaresolverr_proxy", to_str(data['general']['flaresolverr_proxy']))
                 section.save("english", to_str(data['general']['english']))
                 section.save("surround", to_str(data['general']['surround']))
-                section.save("closed_myjd_tab", to_str(data['general']['closed_myjd_tab']))
                 section.save("one_mirror_policy", to_str(data['general']['one_mirror_policy']))
                 section.save("packages_per_myjd_page", to_str(data['general']['packages_per_myjd_page']))
 
@@ -518,7 +527,6 @@ def app_container():
                 sj = hostnames.get('sj')
                 dj = hostnames.get('dj')
                 sf = hostnames.get('sf')
-                pl = hostnames.get('pl')
                 ww = hostnames.get('ww')
                 nk = hostnames.get('nk')
                 by = hostnames.get('by')
@@ -529,11 +537,10 @@ def app_container():
                 sj = sj.replace("s", "S", 1).replace("j", "J", 1)
                 dj = dj.replace("d", "D", 1).replace("j", "J", 1)
                 sf = sf.replace("s", "S", 1).replace("f", "F", 1)
-                pl = pl.replace("p", "P", 1).replace("l", "L", 1)
                 ww = ww.replace("w", "W", 2)
                 nk = nk.replace("n", "N", 1).replace("k", "K", 1)
                 by = by.replace("b", "B", 1)
-                bl = ' / '.join(list(filter(None, [fx, pl, ff, hw, ww, nk, by])))
+                bl = ' / '.join(list(filter(None, [fx, ff, hw, ww, nk, by])))
                 s = ' / '.join(list(filter(None, [sj, sf])))
                 f = ' / '.join(list(filter(None, [ff, sf])))
                 sjbl = ' / '.join(list(filter(None, [s, bl])))
@@ -550,8 +557,6 @@ def app_container():
                     dj = "Nicht gesetzt!"
                 if not sf:
                     sf = "Nicht gesetzt!"
-                if not pl:
-                    pl = "Nicht gesetzt!"
                 if not ww:
                     ww = "Nicht gesetzt!"
                 if not nk:
@@ -577,7 +582,6 @@ def app_container():
                             "hw": hw,
                             "ff": ff,
                             "nk": nk,
-                            "pl": pl,
                             "ww": ww,
                             "bl": bl,
                             "s": s,
@@ -609,7 +613,6 @@ def app_container():
                                 "HW": check("HW_normal", db_status),
                                 "FF": check("FF_normal", db_status),
                                 "NK": check("NK_normal", db_status),
-                                "PL": check("PL_normal", db_status),
                                 "WW": check("WW_normal", db_status)
                             },
                             "flaresolverr": {
@@ -621,7 +624,6 @@ def app_container():
                                 "HW": check("HW_flaresolverr", db_status),
                                 "FF": check("FF_flaresolverr", db_status),
                                 "NK": check("NK_flaresolverr", db_status),
-                                "PL": check("PL_flaresolverr", db_status),
                                 "WW": check("WW_flaresolverr", db_status)
                             },
                             "flaresolverr_proxy": {
@@ -633,7 +635,6 @@ def app_container():
                                 "HW": check("HW_flaresolverr_proxy", db_status),
                                 "FF": check("FF_flaresolverr_proxy", db_status),
                                 "NK": check("NK_flaresolverr_proxy", db_status),
-                                "PL": check("PL_flaresolverr_proxy", db_status),
                                 "WW": check("WW_flaresolverr_proxy", db_status)
                             }
                         }
@@ -651,14 +652,14 @@ def app_container():
         if request.method == 'POST':
             try:
                 FeedDb('crawltimes').store("startnow", "True")
-                i = 3
+                i = 15
                 started = False
                 while i > 0:
                     if not FeedDb('crawltimes').retrieve("startnow"):
                         started = True
                         break
                     i -= 1
-                    time.sleep(5)
+                    time.sleep(1)
                 if started:
                     return "Success", 200
                 else:
@@ -668,12 +669,19 @@ def app_container():
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/api/search/<title>", methods=['GET'])
+    @app.route(prefix + "/api/search/<title>", methods=['POST'])
     @requires_auth
     def search_title(title):
-        if request.method == 'GET':
+        if request.method == 'POST':
             try:
-                results = search.get(title)
+                data = json.loads(request.data)
+                slow_only = data['slow_only']
+                fast_only = data['fast_only']
+            except:
+                slow_only = False
+                fast_only = False
+            try:
+                results = search.get(title, slow_only=slow_only, fast_only=fast_only)
                 return jsonify(
                     {
                         "results": {
@@ -845,6 +853,33 @@ def app_container():
         else:
             return "Failed", 405
 
+    @app.route(prefix + "/api/myjd_reset/<linkids>&<uuids>", methods=['POST'])
+    @requires_auth
+    def myjd_reset(linkids, uuids):
+        if request.method == 'POST':
+            try:
+                linkids_raw = ast.literal_eval(linkids)
+                linkids = []
+                if isinstance(linkids_raw, (list, tuple)):
+                    for linkid in linkids_raw:
+                        linkids.append(linkid)
+                else:
+                    linkids.append(linkids_raw)
+                uuids_raw = ast.literal_eval(uuids)
+                uuids = []
+                if isinstance(uuids_raw, (list, tuple)):
+                    for uuid in uuids_raw:
+                        uuids.append(uuid)
+                else:
+                    uuids.append(uuids_raw)
+                if reset_in_downloads(linkids, uuids):
+                    return "Success", 200
+            except:
+                pass
+            return "Failed", 400
+        else:
+            return "Failed", 405
+
     @app.route(prefix + "/api/internal_remove/<name>", methods=['POST'])
     @requires_auth
     def internal_remove(name):
@@ -888,19 +923,6 @@ def app_container():
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/api/myjd_update/", methods=['POST'])
-    @requires_auth
-    def myjd_update():
-        if request.method == 'POST':
-            try:
-                if update_jdownloader():
-                    return "Success", 200
-            except:
-                pass
-            return "Failed", 400
-        else:
-            return "Failed", 405
-
     @app.route(prefix + "/api/myjd_start/", methods=['POST'])
     @requires_auth
     def myjd_start():
@@ -941,100 +963,18 @@ def app_container():
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/api/myjd_cnl/<uuid>", methods=['POST'])
-    @requires_auth
-    def myjd_cnl(uuid):
-        if request.method == 'POST':
-            try:
-                failed = get_info()
-                if failed:
-                    decrypted_packages = failed[4][1]
-                    offline_packages = failed[4][2]
-                    failed_packages = failed[4][3]
-                else:
-                    failed_packages = False
-                    decrypted_packages = False
-                if not failed_packages:
-                    return "Failed", 500
-
-                title = False
-                old_package = False
-                if failed_packages:
-                    for op in failed_packages:
-                        if str(op['uuid']) == str(uuid):
-                            title = op['name']
-                            old_package = op
-                            break
-
-                if not old_package or not title:
-                    return "Failed", 500
-
-                known_packages = []
-                if decrypted_packages:
-                    for dp in decrypted_packages:
-                        known_packages.append(dp['uuid'])
-                if offline_packages:
-                    for op in offline_packages:
-                        known_packages.append(op['uuid'])
-
-                cnl_package = False
-                grabber_was_collecting = False
-                i = 12
-                while i > 0:
-                    i -= 1
-                    time.sleep(5)
-                    if get_info():
-                        grabber_collecting = failed[2]
-                        if grabber_was_collecting or grabber_collecting:
-                            grabber_was_collecting = grabber_collecting
-                            i -= 1
-                            time.sleep(5)
-                        else:
-                            if not grabber_collecting:
-                                decrypted_packages = failed[4][1]
-                                offline_packages = failed[4][2]
-                                another_device = package_merge(decrypted_packages, title, known_packages)[0]
-                                if another_device:
-                                    info = get_info()
-                                    if info:
-                                        grabber_collecting = info[2]
-                                        decrypted_packages = info[4][1]
-                                        offline_packages = info[4][2]
-
-                                if not grabber_collecting and decrypted_packages:
-                                    for dp in decrypted_packages:
-                                        if dp['uuid'] not in known_packages:
-                                            cnl_package = dp
-                                            i = 0
-                                if not grabber_collecting and offline_packages:
-                                    for op in offline_packages:
-                                        if op['uuid'] not in known_packages:
-                                            cnl_package = op
-                                            i = 0
-
-                if not cnl_package:
-                    return "No Package added through Click'n'Load in time!", 504
-
-                replaced = do_package_replace(old_package, cnl_package)
-                if replaced:
-                    return "Success", 200
-            except:
-                pass
-            return "Failed", 400
-        else:
-            return "Failed", 405
-
     @app.route(prefix + "/api/internal_cnl/<name>&<password>", methods=['POST'])
     @requires_auth
     def internal_cnl(name, password):
         if request.method == 'POST':
             try:
-                failed = get_info()
-                if failed:
-                    decrypted_packages = failed[4][1]
-                    offline_packages = failed[4][2]
+                packages = get_info()
+                if packages:
+                    decrypted_packages = packages[4][1]
+                    offline_packages = packages[4][2]
                 else:
                     decrypted_packages = False
+                    offline_packages = False
 
                 known_packages = []
                 if decrypted_packages:
@@ -1050,17 +990,17 @@ def app_container():
                 while i > 0:
                     i -= 1
                     time.sleep(5)
-                    failed = get_info()
-                    if failed:
-                        grabber_collecting = failed[2]
+                    packages = get_info()
+                    if packages:
+                        grabber_collecting = packages[2]
                         if grabber_was_collecting or grabber_collecting:
                             grabber_was_collecting = grabber_collecting
                             i -= 1
                             time.sleep(5)
                         else:
                             if not grabber_collecting:
-                                decrypted_packages = failed[4][1]
-                                offline_packages = failed[4][2]
+                                decrypted_packages = packages[4][1]
+                                offline_packages = packages[4][2]
                                 if not grabber_collecting and decrypted_packages:
                                     for dp in decrypted_packages:
                                         if dp['uuid'] not in known_packages:
@@ -1142,21 +1082,6 @@ def app_container():
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/redirect_user/<target>", methods=['GET'])
-    @requires_auth
-    def redirect_user(target):
-        if request.method == 'GET':
-            try:
-                if target == "captcha":
-                    return redirect("http://getcaptchasolution.com/zuoo67f5cq", code=302)
-                elif target == "multihoster":
-                    return redirect("http://linksnappy.com/?ref=397097", code=302)
-            except:
-                pass
-            return "Failed", 400
-        else:
-            return "Failed", 405
-
     @app.route(prefix + "/sponsors_helper/feedcrawler_helper_sj.user.js", methods=['GET'])
     @requires_auth
     def feedcrawler_helper_sj():
@@ -1222,7 +1147,7 @@ if (title) {
 // @name            FeedCrawler Sponsors Helper (SJ/DJ)
 // @author          rix1337
 // @description     Clicks the correct download button on SJ/DJ sub pages to speed up Click'n'Load
-// @version         0.5.1
+// @version         0.5.2
 // @require         https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js
 // @match           https://""" + sj + """/*
 // @match           https://""" + dj + """/*
@@ -1266,16 +1191,13 @@ if (title && title !== "login") {
             $(".container").show();
             $("tr:contains('" + title + "')")[0].lastChild.firstChild.click();
             if (i > 24) {
-                if (sponsorsHelper) {
-                    const requiresLogin = $(".alert-warning").length;
-                    if (requiresLogin) {
-                        console.log("[FeedCrawler Sponsors Helper] Login required for: " + title);
-                        clearInterval(checkExist);
-                        window.open("https://" + $(location).attr('hostname') + "#login|" + btoa(window.location));
-                        window.close();
-                    }
+                const requiresLogin = $(".alert-warning").length;
+                if (requiresLogin) {
+                    console.log("[FeedCrawler Sponsors Helper] Login required for: " + title);
+                    clearInterval(checkExist);
+                    window.open("https://" + $(location).attr('hostname') + "#login|" + btoa(window.location));
+                    window.close();
                 }
-                console.log("hit")
                 clearInterval(checkExist);
             } else {
                 console.log("miss")
@@ -1328,14 +1250,21 @@ if (title && title !== "login") {
         if not helper_active:
             return "Forbidden", 403
         if request.method == 'GET':
+            hostnames = CrawlerConfig('Hostnames')
+            fx = hostnames.get('fx')
+            sf = hostnames.get('sf')
             try:
                 return """// ==UserScript==
 // @name            FeedCrawler Sponsors Helper (FC)
 // @author          rix1337
 // @description     Forwards Click'n'Load to FeedCrawler
-// @version         0.5.1
+// @version         0.7.4
 // @match           *.filecrypt.cc/*
 // @match           *.filecrypt.co/*
+// @match           *.filecrypt.to/*
+// @exclude         http://filecrypt.cc/helper.html*
+// @exclude         http://filecrypt.co/helper.html*
+// @exclude         http://filecrypt.to/helper.html*
 // @grant           window.close
 // ==/UserScript==
 
@@ -1355,32 +1284,50 @@ function Sleep(milliseconds) {
     return new Promise(resolve => setTimeout(resolve, milliseconds));
 }
 
-const fx = (document.getElementById("customlogo").getAttribute('src') === '/css/custom/f38ed.png');
+let pw = "";
 
-const checkFxPass = setInterval(function () {
+
+let fx = false
+try {
+    fx = (document.getElementById("customlogo").getAttribute('src') === '/css/custom/f38ed.png')
+} catch {
+}
+
+const checkPass = setInterval(function () {
 	if (document.getElementById("p4assw0rt")) {
-		if (fx) {
-			const pw = atob('ZnVueGQ=');
-			console.log("[FeedCrawler Sponsors Helper] entering Password: " + pw);
+		if (password) {
+			pw = password;
+		} else if (fx) {
+			pw = '""" + fx.split('.')[0] + """';
+		} else {
+			pw = '""" + sf + """';
+		}
+	} else {
+		pw = "";
+	}
+	clearInterval(checkPass);
+}, 100);
+
+const enterPass = setInterval(function () {
+	if (pw) {
+		console.log("[FeedCrawler Sponsors Helper] entering Password: " + pw);
+		try {
 			document.getElementById("p4assw0rt").value = pw;
 			document.getElementById("p4assw0rt").parentNode.nextElementSibling.click();
+		} catch (e) {
+			console.log("[FeedCrawler Sponsors Helper] Password set Error: " + e);
 		}
-		clearInterval(checkFxPass);
+		clearInterval(enterPass);
 	}
 }, 100);
 
-
-const checkSFPass = setInterval(function () {
-	if (document.getElementById("p4assw0rt") && !fx) {
-		const pw = atob('c2VyaWVuZmFucy5vcmc=');
-		console.log("[FeedCrawler Sponsors Helper] entering Password: " + pw);
-		document.getElementById("p4assw0rt").value = pw;
-		document.getElementById("p4assw0rt").parentNode.nextElementSibling.click();
-		clearInterval(checkSFPass);
+const checkAd = setInterval(function () {
+	if (document.querySelector('#cform > div > div > div > div > ul > li:nth-child(2)') !== null) {
+		document.querySelector('#cform > div > div > div > div > ul > li:nth-child(2)').style.display = 'none';
+		clearInterval(checkAd);
 	}
 }, 100);
 
-
 let mirrorsAvailable = false;
 try {
 	mirrorsAvailable = document.querySelector('.mirror').querySelectorAll("a");
@@ -1425,7 +1372,7 @@ const cnlExists = setInterval(async function () {
 		clearInterval(cnlExists);
 		document.getElementById("cnl_btn").click();
 		console.log("[FeedCrawler Sponsors Helper] attempting Click'n'Load");
-		await Sleep(30000);
+		await Sleep(10000);
 		window.close();
 	}
 }, 100);
@@ -1435,15 +1382,6 @@ const cnlExists = setInterval(async function () {
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/sponsors_helper/", methods=['GET'])
-    def to_decrypt():
-        global helper_active
-        helper_active = True
-        if request.method == 'GET':
-            return render_template('helper.html')
-        else:
-            return "Failed", 405
-
     @app.route(prefix + "/sponsors_helper/api/to_decrypt/", methods=['GET'])
     def to_decrypt_api():
         global helper_active
@@ -1595,34 +1533,31 @@ const cnlExists = setInterval(async function () {
                                 if not internal.device or not is_device(internal.device):
                                     return "Failed", 500
                                 packages = get_packages_in_linkgrabber()
+
                             if packages:
                                 failed = packages[0]
                                 offline = packages[1]
+
+                                def check_if_broken(check_packages):
+                                    if check_packages:
+                                        for check_package in check_packages:
+                                            if re.match(re.compile(re_name), check_package['name'].lower()):
+                                                episode = re.findall(r'.*\.S\d{1,3}E(\d{1,3})\..*',
+                                                                     check_package['name'])
+                                                if episode:
+                                                    FeedDb('episode_remover').store(package_name, str(int(episode[0])))
+                                                linkids = check_package['linkids']
+                                                uuids = [check_package['uuid']]
+                                                remove_from_linkgrabber(linkids, uuids)
+                                                remove_decrypt(package_name)
+                                                return True
+
                                 try:
-                                    if failed:
-                                        for package in failed:
-                                            if re.match(re.compile(re_name), package['name'].lower()):
-                                                episode = re.findall(r'.*\.S\d{1,3}E(\d{1,3})\..*', package['name'])
-                                                if episode:
-                                                    FeedDb('episode_remover').store(package_name, str(int(episode[0])))
-                                                linkids = package['linkids']
-                                                uuids = [package['uuid']]
-                                                remove_from_linkgrabber(linkids, uuids)
-                                                remove_decrypt(package_name)
-                                                break
-                                    if offline:
-                                        for package in offline:
-                                            if re.match(re.compile(re_name), package['name'].lower()):
-                                                episode = re.findall(r'.*\.S\d{1,3}E(\d{1,3})\..*', package['name'])
-                                                if episode:
-                                                    FeedDb('episode_remover').store(package_name, str(int(episode[0])))
-                                                linkids = package['linkids']
-                                                uuids = [package['uuid']]
-                                                remove_from_linkgrabber(linkids, uuids)
-                                                remove_decrypt(package_name)
-                                                break
+                                    check_if_broken(failed)
+                                    check_if_broken(offline)
                                 except:
                                     pass
+
                             packages = get_to_decrypt()
                             if packages:
                                 for package in packages:
